@@ -29,6 +29,7 @@ mod compilation;
 mod module;
 mod module_environ;
 pub mod obj;
+mod ref_bits;
 mod stack_map;
 mod trap_encoding;
 mod tunables;
@@ -39,6 +40,7 @@ pub use crate::builtin::*;
 pub use crate::compilation::*;
 pub use crate::module::*;
 pub use crate::module_environ::*;
+pub use crate::ref_bits::*;
 pub use crate::stack_map::StackMap;
 pub use crate::trap_encoding::*;
 pub use crate::tunables::Tunables;
